@@ -38,13 +38,12 @@ class CommandShodan(Command):
         parser_c = subparsers.add_parser('ssh', help='Write ssh history from Shodan historical data')
         parser_c.add_argument('IP', help='IP address')
         parser_c.set_defaults(subcommand='ssh')
+        parser_d = subparsers.add_parser('quota', help='Information on quota of your shodan account')
+        parser_d.set_defaults(subcommand='quota')
         self.parser = parser
 
     def run(self, conf, args, plugins):
         if 'subcommand' in args:
-            if 'Shodan' not in conf and 'key' not in conf['Shodan']:
-                print('Bad configuration for Shodan, quitting...')
-                sys.exit(1)
             api = shodan.Shodan(conf['Shodan']['key'])
             if args.subcommand == 'ip':
                 try:
@@ -140,7 +139,26 @@ class CommandShodan(Command):
                                 val['last'].strftime('%Y-%m-%d')
                             )
                         )
+            elif args.subcommand == 'quota':
+                res = api.info()
+                print(json.dumps(res, sort_keys=True, indent=4))
             else:
                 self.parser.print_help()
         else:
             self.parser.print_help()
+
+    def intel(self, type, query, data, conf):
+        if type == "ip":
+            print("[+] Checking Shodan...")
+            api = shodan.Shodan(conf['Shodan']['key'])
+            try:
+                res = api.host(query)
+            except shodan.exception.APIError:
+                pass
+            else:
+                for p in res["ports"]:
+                    data["ports"].append({
+                        "port": p,
+                        "source": "Shodan",
+                        "info": ""
+                    })
